@@ -136,7 +136,7 @@ class ServiceName:
             file -- HTML file name
             parts -- Anchor parts
         """
-        link = f"{self.local_doc_link}{file}.html"
+        link = f"./{file}.md"
         if not parts:
             return link
         anchor = "".join([get_anchor_link(part) for part in parts])
